import { T as TestFactory, S as SuiteCollector, a as TestFunction, b as SuiteHooks, U as UserOptions } from './types-c0d293d3';
export { C as CliOptions, e as ComputeMode, u as Environment, E as EnvironmentReturn, F as File, G as GlobalContext, H as HookListener, M as ModuleCache, m as Reporter, R as ResolvedConfig, w as RpcCall, v as RpcMap, y as RpcPayload, x as RpcSend, c as RunMode, n as SnapshotData, q as SnapshotMatchOptions, r as SnapshotResult, p as SnapshotStateOptions, t as SnapshotSummary, o as SnapshotUpdateState, i as Suite, S as SuiteCollector, b as SuiteHooks, k as Task, f as TaskBase, g as TaskResult, h as TaskResultPack, d as TaskState, j as Test, l as TestCollector, T as TestFactory, a as TestFunction, s as UncheckedSnapshot, U as UserOptions, V as VitestContext, W as WorkerContext } from './types-c0d293d3';
export { assert, default as chai, expect, should } from 'chai';
import sinon from 'sinon';
export { default as sinon } from 'sinon';
import 'worker_threads';
import '@antfu/utils';
import 'vite';
import 'pretty-format';

declare const suite: {
    (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
    concurrent: {
        (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        skip(suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        only(suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        todo(suiteName: string): SuiteCollector;
    };
    skip: {
        (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        concurrent: (suiteName: string, factory?: TestFactory | undefined) => SuiteCollector;
    };
    only: {
        (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        concurrent: (suiteName: string, factory?: TestFactory | undefined) => SuiteCollector;
    };
    todo: {
        (suiteName: string): SuiteCollector;
        concurrent: (suiteName: string) => SuiteCollector;
    };
};
declare const defaultSuite: SuiteCollector;
declare function createSuiteHooks(): {
    beforeAll: never[];
    afterAll: never[];
    beforeEach: never[];
    afterEach: never[];
};
declare const test: {
    (name: string, fn: TestFunction, timeout?: number | undefined): void;
    concurrent: {
        (name: string, fn: TestFunction, timeout?: number | undefined): void;
        skip(name: string, fn: TestFunction, timeout?: number | undefined): void;
        only(name: string, fn: TestFunction, timeout?: number | undefined): void;
        todo(name: string): void;
    };
    skip: {
        (name: string, fn: TestFunction, timeout?: number | undefined): void;
        concurrent(name: string, fn: TestFunction, timeout?: number | undefined): void;
    };
    only: {
        (name: string, fn: TestFunction, timeout?: number | undefined): void;
        concurrent(name: string, fn: TestFunction, timeout?: number | undefined): void;
    };
    todo: {
        (name: string): void;
        concurrent(name: string): void;
    };
};
declare const describe: {
    (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
    concurrent: {
        (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        skip(suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        only(suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        todo(suiteName: string): SuiteCollector;
    };
    skip: {
        (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        concurrent: (suiteName: string, factory?: TestFactory | undefined) => SuiteCollector;
    };
    only: {
        (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        concurrent: (suiteName: string, factory?: TestFactory | undefined) => SuiteCollector;
    };
    todo: {
        (suiteName: string): SuiteCollector;
        concurrent: (suiteName: string) => SuiteCollector;
    };
};
declare const it: {
    (name: string, fn: TestFunction, timeout?: number | undefined): void;
    concurrent: {
        (name: string, fn: TestFunction, timeout?: number | undefined): void;
        skip(name: string, fn: TestFunction, timeout?: number | undefined): void;
        only(name: string, fn: TestFunction, timeout?: number | undefined): void;
        todo(name: string): void;
    };
    skip: {
        (name: string, fn: TestFunction, timeout?: number | undefined): void;
        concurrent(name: string, fn: TestFunction, timeout?: number | undefined): void;
    };
    only: {
        (name: string, fn: TestFunction, timeout?: number | undefined): void;
        concurrent(name: string, fn: TestFunction, timeout?: number | undefined): void;
    };
    todo: {
        (name: string): void;
        concurrent(name: string): void;
    };
};
declare const beforeAll: (fn: SuiteHooks['beforeAll'][0], timeout?: number) => void;
declare const afterAll: (fn: SuiteHooks['afterAll'][0], timeout?: number) => void;
declare const beforeEach: (fn: SuiteHooks['beforeEach'][0], timeout?: number) => void;
declare const afterEach: (fn: SuiteHooks['afterEach'][0], timeout?: number) => void;
declare function clearContext(): void;

declare const mock: sinon.SinonMockStatic;
declare const spy: sinon.SinonSpyStatic;
declare const stub: sinon.SinonStubStatic;

declare module 'vite' {
    interface UserConfig {
        /**
         * Options for Vitest
         */
        test?: UserOptions;
    }
}
declare global {
    namespace Chai {
        interface Assertion {
            toMatchSnapshot(message?: string): Assertion;
            matchSnapshot(message?: string): Assertion;
            toEqual(expected: any): void;
            toStrictEqual(expected: any): void;
            toBe(expected: any): void;
            toMatch(expected: string | RegExp): void;
            toMatchObject(expected: any): void;
            toContain(item: any): void;
            toContainEqual(item: any): void;
            toBeTruthy(): void;
            toBeFalsy(): void;
            toBeGreaterThan(num: number): void;
            toBeGreaterThanOrEqual(num: number): void;
            toBeLessThan(num: number): void;
            toBeLessThanOrEqual(num: number): void;
            toBeNaN(): void;
            toBeUndefined(): void;
            toBeNull(): void;
            toBeDefined(): void;
            toBeInstanceOf(c: any): void;
            toBeCalledTimes(n: number): void;
            toHaveLength(l: number): void;
            toBeCloseTo(number: number, numDigits?: number): void;
            toHaveBeenCalledTimes(n: number): void;
            toHaveBeenCalledOnce(): void;
            toHaveBeenCalled(): void;
            toBeCalled(): void;
            toHaveBeenCalledWith(...args: any[]): void;
            toBeCalledWith(...args: any[]): void;
            toHaveBeenNthCalledWith(n: number, ...args: any[]): void;
            nthCalledWith(n: number, ...args: any[]): void;
            toHaveBeenLastCalledWith(...args: any[]): void;
            lastCalledWith(...args: any[]): void;
            toThrow(expected?: string | RegExp): void;
            toThrowError(expected?: string | RegExp): void;
            toReturn(): void;
            toHaveReturned(): void;
            toReturnTimes(times: number): void;
            toHaveReturnedTimes(times: number): void;
            toReturnWith(value: any): void;
            toHaveReturnedWith(value: any): void;
            toHaveLastReturnedWith(value: any): void;
            lastReturnedWith(value: any): void;
            toHaveNthReturnedWith(nthCall: number, value: any): void;
            nthReturnedWith(nthCall: number, value: any): void;
        }
    }
}

export { afterAll, afterEach, beforeAll, beforeEach, clearContext, createSuiteHooks, defaultSuite, describe, it, mock, spy, stub, suite, test };
